@@ -220,7 +220,7 @@ repo_info = \
 {
     "K3SController":{
         "add_node_label":{
-            "args":["node_infos", ["key", False], ["value", False]],
+            "args":[["node_infos", True, "NodeInfo", None, True], ["key", False], ["value", False]],
             "ret":["command_result", True, None, None, True, True]
         },
         "check_connection":{
@@ -228,7 +228,7 @@ repo_info = \
             "ret":["bool", True, None, None, False, True]
         },
         "create_config_maps":{
-            "args":[["cluster_name", False, "Name"], "config_map_user_settings"]
+            "args":[["cluster_name", False, "Name"], ["config_map_user_settings", True, "ConfigMapUserSetting", None, True]]
         },
         "create_namespace":{
             "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]]
@@ -241,10 +241,10 @@ repo_info = \
             "args":[["cluster_name", False, "Name"], ["target_paths", False, "Path", None, True]]
         },
         "create_secrets":{
-            "args":[["cluster_name", False, "Name"], "secret_user_settings"]
+            "args":[["cluster_name", False, "Name"], ["secret_user_settings", True, "SecretUserSetting", None, True]]
         },
         "delete_nodes":{
-            "args":["node_infos"]
+            "args":[["node_infos", True, "NodeInfo", None, True]]
         },
         "delete_resource_from_oss":{
             "args":[["cluster_name", False, "Name"], ["target_paths", False, "Path", None, True]]
@@ -282,7 +282,7 @@ repo_info = \
             "ret":["secret", True, None, None, True, True]
         },
         "upload_to_oss_from_pod":{
-            "args":["pod_oss_operation_info"]
+            "args":[["pod_oss_operation_info", True, "PodOSSOperationInfo"]]
         }
     }
 }
